==> react-form-mobx-0.1.0.tgz: package/es/DemonButton.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2, _initialiseProps;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Component, Children } from 'react';
import PropTypes from 'prop-types';
import { isFunction, warn } from './utils';
import withFormStore from './withFormStore';

var DemonButton = (_dec = withFormStore(), _dec(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(DemonButton, _Component);

	function DemonButton() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, DemonButton);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DemonButton.__proto__ || Object.getPrototypeOf(DemonButton)).call.apply(_ref, [this].concat(args))), _this), _initialiseProps.call(_this), _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(DemonButton, [{
		key: 'emit',
		value: function emit() {
			var _props = this.props,
			    formStore = _props.formStore,
			    type = _props.type;

			formStore[type]();
		}
	}, {
		key: 'render',
		value: function render() {
			var _extends2;

			var _props2 = this.props,
			    forwardedProps = _props2.forwardedProps,
			    propOnClick = _props2.propOnClick,
			    propOnKeyPress = _props2.propOnKeyPress,
			    children = _props2.children;

			var props = _extends({}, forwardedProps, (_extends2 = {}, _defineProperty(_extends2, propOnClick, this.handleClick), _defineProperty(_extends2, propOnKeyPress, this.handleKeyPress), _extends2));
			return Children.only(children(props));
		}
	}]);

	return DemonButton;
}(Component), _class2.propTypes = {
	children: PropTypes.func.isRequired,
	type: PropTypes.oneOf(['submit', 'reset', 'clear']),
	formStore: PropTypes.shape({
		disabled: PropTypes.bool
	}).isRequired,
	forwardedProps: PropTypes.object,
	getKeyFromKeyPressEvent: PropTypes.func,
	propOnClick: PropTypes.string,
	propOnKeyPress: PropTypes.string
}, _class2.defaultProps = {
	forwardedProps: {},
	type: 'submit',
	getKeyFromKeyPressEvent: function getKeyFromKeyPressEvent(ev) {
		return ev.key;
	},
	propOnClick: 'onClick',
	propOnKeyPress: 'onKeyPress'
}, _initialiseProps = function _initialiseProps() {
	var _this2 = this;

	this.handleClick = function () {
		var _props3 = _this2.props,
		    forwardedProps = _props3.forwardedProps,
		    propOnClick = _props3.propOnClick;

		var onClick = forwardedProps[propOnClick];
		if (isFunction(onClick)) onClick.apply(undefined, arguments);
		_this2.emit();
	};

	this.handleKeyPress = function () {
		var _props4 = _this2.props,
		    forwardedProps = _props4.forwardedProps,
		    propOnKeyPress = _props4.propOnKeyPress,
		    getKeyFromKeyPressEvent = _props4.getKeyFromKeyPressEvent;

		var onKeyPress = forwardedProps[propOnKeyPress];
		if (isFunction(onKeyPress)) onKeyPress.apply(undefined, arguments);
		try {
			var key = getKeyFromKeyPressEvent.apply(undefined, arguments);

			/* istanbul ignore else */
			if (key === 'Enter') _this2.emit();
		} catch (err) /* istanbul ignore next */{
			warn('Failed to map value from "' + propOnKeyPress + '",', 'changing "props.getKeyFromKeyPressEvent" may resolve this problem.');
			console.error(err);
		}
	};
}, _temp2)) || _class);
export { DemonButton as default };

==> react-form-mobx-0.6.0.tgz: package/es/DemonButton.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2, _initialiseProps;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { Component, Children } from 'react';
import PropTypes from 'prop-types';
import { isFunction, warn } from './utils';
import withFormStore from './withFormStore';

var DemonButton = (_dec = withFormStore(), _dec(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(DemonButton, _Component);

	function DemonButton() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, DemonButton);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DemonButton.__proto__ || Object.getPrototypeOf(DemonButton)).call.apply(_ref, [this].concat(args))), _this), _initialiseProps.call(_this), _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(DemonButton, [{
		key: 'emit',
		value: function emit() {
			var _props = this.props,
			    formStore = _props.formStore,
			    type = _props.type;

			formStore[type]();
		}
	}, {
		key: 'render',
		value: function render() {
			var _extends2;

			var _props2 = this.props,
			    forwardedProps = _props2.forwardedProps,
			    propOnClick = _props2.propOnClick,
			    propOnKeyPress = _props2.propOnKeyPress,
			    children = _props2.children;

			var props = _extends({}, forwardedProps, (_extends2 = {}, _defineProperty(_extends2, propOnClick, this.handleClick), _defineProperty(_extends2, propOnKeyPress, this.handleKeyPress), _extends2));
			return Children.only(children(props));
		}
	}]);

	return DemonButton;
}(Component), _class2.propTypes = {
	children: PropTypes.func.isRequired,
	type: PropTypes.oneOf(['submit', 'reset', 'clear']),
	formStore: PropTypes.shape({
		disabled: PropTypes.bool
	}).isRequired,
	forwardedProps: PropTypes.object,
	getKeyFromKeyPressEvent: PropTypes.func,
	propOnClick: PropTypes.string,
	propOnKeyPress: PropTypes.string
}, _class2.defaultProps = {
	forwardedProps: {},
	type: 'submit',
	getKeyFromKeyPressEvent: function getKeyFromKeyPressEvent(ev) {
		return ev.key;
	},
	propOnClick: 'onClick',
	propOnKeyPress: 'onKeyPress'
}, _initialiseProps = function _initialiseProps() {
	var _this2 = this;

	this.handleClick = function () {
		var _props3 = _this2.props,
		    forwardedProps = _props3.forwardedProps,
		    propOnClick = _props3.propOnClick;

		var onClick = forwardedProps[propOnClick];
		if (isFunction(onClick)) onClick.apply(undefined, arguments);
		_this2.emit();
	};

	this.handleKeyPress = function () {
		var _props4 = _this2.props,
		    forwardedProps = _props4.forwardedProps,
		    propOnKeyPress = _props4.propOnKeyPress,
		    getKeyFromKeyPressEvent = _props4.getKeyFromKeyPressEvent;

		var onKeyPress = forwardedProps[propOnKeyPress];
		if (isFunction(onKeyPress)) onKeyPress.apply(undefined, arguments);
		try {
			var key = getKeyFromKeyPressEvent.apply(undefined, arguments);

			/* istanbul ignore else */
			if (key === 'Enter') _this2.emit();
		} catch (err) /* istanbul ignore next */{
			warn('Failed to get value from "' + propOnKeyPress + '",', 'changing "props.getKeyFromKeyPressEvent" may resolve this problem.');
			console.error(err);
		}
	};
}, _temp2)) || _class);
export { DemonButton as default };
